cemento.axioms package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cemento.axioms.modules

Submodules
----------

cemento.axioms.constants module
-------------------------------

.. automodule:: cemento.axioms.constants
   :members:
   :undoc-members:
   :show-inheritance:

cemento.axioms.extract\_axioms module
-------------------------------------

.. automodule:: cemento.axioms.extract_axioms
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cemento.axioms
   :members:
   :undoc-members:
   :show-inheritance:
